@@ -3,8 +3,9 @@ BEGIN {
   $Task::BeLike::YANICK::AUTHORITY = 'cpan:yanick';
 }
 BEGIN {
-  $Task::BeLike::YANICK::VERSION = '0.5.0';
+  $Task::BeLike::YANICK::VERSION = '0.6.0';
 }
+# ABSTRACT: like Yanick? Be like Yanick!
 
 use warnings;
 use strict;
@@ -18,11 +19,11 @@ __END__
 
 =head1 NAME
 
-Task::BeLike::YANICK
+Task::BeLike::YANICK - like Yanick? Be like Yanick!
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -39,10 +40,6 @@ To do that, do
 
     TASK_UPGRADE=1 cpan -f Task::BeLike::YANICK
 
-=head1 NAME
-
-Task::BeLike::YANICK - like Yanick? Be like Yanick!
-
 =head1 MODULES INSTALLED BY THIS TASK
 
 =head2 General
@@ -94,6 +91,19 @@ Can't leave out my baby, now, can I?
 
 C<grep> is nice, but C<ack> is just nicer.
 
+=item L<App::HTTPThis>
+
+Want to share a directory over http?
+
+    $ cd /path/to/dir/we/wanna/share
+    $ http_this
+
+=item L<Module::Info>
+
+Want to know where the module is?
+
+    module_info Task::BeLike::YANICK
+
 =back
 
 =head2 Web Development
@@ -159,6 +169,10 @@ always either end in success, or death...
 
 Part of the core as of 5.10.1.
 
+=item L<Const::Fast>
+
+First, there was L<constant>, then L<Readonly>, and now L<Const::Fast>.
+
 =item L<Perl::Tidy>
 
 Because tidy code is so easier to read.
@@ -189,6 +203,10 @@ Slam, bang, thank you CPAN.
 
 CPAN asks for it, so there it is.
 
+=item L<App::cpanoutdated>
+
+    cpan-outdated | cpanm
+
 =back
 
 =head2 Dist::Zilla
